pub fn derive_path(parent: &Scalar, path: &DerivationPath) -> ScalarExpand description
Derive a scalar from a parent following a full path.
pub fn derive_path(parent: &Scalar, path: &DerivationPath) -> ScalarDerive a scalar from a parent following a full path.